@@ -1,5 +1,6 @@
 //use crate::parser::Letter;
 use crate::partial::*;
+use transliterate::parser::BackTo;
 //use bogobble::common::*;
 use bogobble::*;
 use std::collections::BTreeMap;
@@ -27,6 +28,8 @@ impl Highlight {
     }
 }
 
+impl BackTo for Highlight {}
+
 impl ParseMark for Highlight {
     fn mark(&self, i: Item, s: &mut String, _: Option<usize>) {
         match self.mp.get(i.name()) {
